

/* I located base code on the ED Forum for outputing A10C radio 
frequencies within DCS to a 7 segment display. This code was 
originally created by FSF Ian who is also the creator of DCS BIOS. 
My adaptation of this is just to duplicate the base code 4 times over
to cover the below
1. VHF AM frequency
2. UHF frequency
3. VHF FM frequency
4. VHF-AM PRESET / UHF PRESET / VHF-FM PRESET
and alter Pin designations accordingly
whilst adding a boot screen as part of the MAX 7219
initialisation sequence

I am currently building a Simpit of the A10C
and documenting its build at:

      www.mysimpit.co.uk

"Commence the joy of Simpit"


/*
Tell DCS-BIOS to use a serial connection and use interrupt-driven
communication. The main program will be interrupted to prioritize
processing incoming data.

This should work on any Arduino that has an ATMega328 controller
(Uno, Pro Mini, many others).
*/

#define DCSBIOS_IRQ_SERIAL
#include <LedControl.h>
#include <DcsBios.h>


//FIRST - 8 DIGIT 7 SEGMENT DISPLAY - VHF-AM RADIO
//pin 13 is connected to the DataIn 
//pin 11 is connected to the CLK 
//pin 12 is connected to LOAD / CS

//SECOND - 8 DIGIT 7 SEGMENT DISPLAY - UHF RADIO
//pin 10 is connected to the DataIn 
//pin 8 is connected to the CLK 
//pin 9 is connected to LOAD / CS

//THIRD - 8 DIGIT 7 SEGMENT DISPLAY - VHF-FM RADIO
//pin 7 is connected to the DataIn 
//pin 5 is connected to the CLK 
//pin 6 is connected to LOAD / CS

//FOURTH - 8 DIGIT 7 SEGMENT DISPLAY - VHF-AM PRESET / UHF PRESET / VHF-FM PRESET
//pin 4 is connected to the DataIn 
//pin 2 is connected to the CLK 
//pin 3 is connected to LOAD / CS


LedControl lc=LedControl(13,11,12,8); //This creates an instance of a single controller named "lc"
LedControl lc2=LedControl(10,8,9,8); //This creates an instance of a single controller named "lc2"
LedControl lc3=LedControl(7,5,6,8); //This creates an instance of a single controller named "lc3"
LedControl lc4=LedControl(4,2,3,8); //This creates an instance of a single controller named "lc4"


// GENERAL REF NOTE BELOW
/*
The sequence of pins used above are in the following order... LedControl(DIN,CLK,LOAD,# OF IC's) 
pin X is connected to the DataIn 
pin X is connected to the CLK 
pin X is connected to LOAD
the last number...(1) is for how many MAX7219 we have daisy chained. (8 STATED, HOWEVER 4 ACTUALLY PRESENT)
*/





//FIRST - 8 DIGIT 7 SEGMENT DISPLAY - VHF-AM RADIO (CODE)

//FUNCTION 1
void onVhfamFreq1Change(char* newValue) {
lc.setChar(0,7,newValue[0],false);
lc.setChar(0,6,newValue[1],false);
}
DcsBios::StringBuffer<2> vhfamFreq1StrBuffer(0x1190, onVhfamFreq1Change);

//FUNCTION 2
void onVhfamFreq2Change(unsigned int newValue) {
lc.setChar(0,4,newValue,true);
}
DcsBios::IntegerBuffer vhfamFreq2Buffer(0x118e, 0x00f0, 4, onVhfamFreq2Change);

//FUNCTION 3
void onVhfamFreq3Change(unsigned int newValue) {
lc.setChar(0,3,newValue,false);
}
DcsBios::IntegerBuffer vhfamFreq3Buffer(0x118e, 0x0f00, 8, onVhfamFreq3Change);

//FUNCTION 4
void onVhfamFreq4Change(char* newValue) {
lc.setChar(0,1,newValue[0],false);
lc.setChar(0,0,newValue[1],false);
}
DcsBios::StringBuffer<2> vhfamFreq4StrBuffer(0x1192, onVhfamFreq4Change);





//SECOND - 8 DIGIT 7 SEGMENT DISPLAY - UHF RADIO (CODE)

void onUhfFrequencyChange(char* newValue) {
lc2.setChar(0,7,newValue[0],false);
lc2.setChar(0,6,newValue[1],false);
lc2.setChar(0,5,newValue[2],true);
lc2.setChar(0,4,newValue[3],false);
lc2.setChar(0,3,newValue[4],false);
lc2.setChar(0,2,newValue[5],false);
lc2.setChar(0,1,newValue[6],false);
}
DcsBios::StringBuffer<7> uhfFrequencyBuffer(0x1180, onUhfFrequencyChange);





//THIRD - 8 DIGIT 7 SEGMENT DISPLAY - VHF-FM RADIO (CODE)

//FUNCTION 1
void onVhffmFreq1Change(char* newValue) {
lc3.setChar(0,7,newValue[0],false);
lc3.setChar(0,6,newValue[1],false);
}
DcsBios::StringBuffer<2> vhffmFreq1StrBuffer(0x119a, onVhffmFreq1Change);

//FUNCTION 2
void onVhffmFreq2Change(unsigned int newValue) {
lc3.setChar(0,4,newValue,true);
}
DcsBios::IntegerBuffer vhffmFreq2Buffer(0x119c, 0x000f, 0, onVhffmFreq2Change);

//FUNCTION 3
void onVhffmFreq3Change(unsigned int newValue) {
lc3.setChar(0,3,newValue,false);
}
DcsBios::IntegerBuffer vhffmFreq3Buffer(0x119c, 0x00f0, 4, onVhffmFreq3Change);

//FUNCTION 4
void onVhffmFreq4Change(char* newValue) {
lc3.setChar(0,1,newValue[0],false);
lc3.setChar(0,0,newValue[1],false);
}
DcsBios::StringBuffer<2> vhffmFreq4StrBuffer(0x119e, onVhffmFreq4Change);





//FOURTH - 8 DIGIT 7 SEGMENT DISPLAY - VHF-AM PRESET / UHF PRESET / VHF-FM PRESET (CODE)

//VHF-AM PRESET
void onVhfamPresetChange(char* newValue) {
lc4.setChar(0,1,newValue[1],false);
lc4.setChar(0,0,newValue[0],false);
}
DcsBios::StringBuffer<2> vhfamPresetStrBuffer(0x118a, onVhfamPresetChange);

//UHF PRESET
void onUhfPresetSelChange(char* newValue) {
lc4.setChar(0,3,newValue[1],false);
lc4.setChar(0,2,newValue[0],false);
}
DcsBios::StringBuffer<2> uhfPresetSelStrBuffer(0x1176, onUhfPresetSelChange);

//VHF-FM PRESET
void onVhffmPresetChange(char* newValue) {
lc4.setChar(0,5,newValue[1],false);
lc4.setChar(0,4,newValue[0],false);
}
DcsBios::StringBuffer<2> vhffmPresetStrBuffer(0x1196, onVhffmPresetChange);


void setup() {
DcsBios::setup();




// MAX7219 INITIALISATION
//This initializes the MAX7219 and gets it ready for use:





//FIRST - 8 DIGIT 7 SEGMENT DISPLAY - VHF-AM RADIO (CODE) MAX7219 INITIALISATION
lc.shutdown(0,false); //turn on the display
lc.setIntensity(0,8);//set the brightness 
lc.clearDisplay(0); //clear the display 

//FIRST - 8 DIGIT 7 SEGMENT DISPLAY - VHF-AM RADIO (CODE) MAX7219 BOOT CODE WHILST AWAITING SOCAT DATA STREAM
// 
lc.setChar(0,7,'A',false);
lc.setChar(0,6,'1',false);
lc.setChar(0,4,'0',false);
lc.setChar(0,3,'c',false);



//SECOND - 8 DIGIT 7 SEGMENT DISPLAY - UHF RADIO (CODE) MAX7219 INITIALISATION
lc2.shutdown(0,false); //turn on the display
lc2.setIntensity(0,8);//set the brightness 
lc2.clearDisplay(0); //clear the display 

//SECOND - 8 DIGIT 7 SEGMENT DISPLAY - UHF RADIO (CODE) MAX7219 BOOT CODE WHILST AWAITING SOCAT DATA STREAM
// 
lc2.setChar(0,7,'A',false);
lc2.setChar(0,6,'1',false);
lc2.setChar(0,5,'0',false);

lc2.setChar(0,3,'c',false);




//THIRD - 8 DIGIT 7 SEGMENT DISPLAY - VHF-FM RADIO (CODE) MAX7219 INITIALISATION
lc3.shutdown(0,false); //turn on the display
lc3.setIntensity(0,8);//set the brightness 
lc3.clearDisplay(0); //clear the display 

//THIRD - 8 DIGIT 7 SEGMENT DISPLAY - VHF-FM RADIO (CODE) MAX7219 BOOT CODE WHILST AWAITING SOCAT DATA STREAM
// 
lc3.setChar(0,7,'A',false);
lc3.setChar(0,6,'1',false);
lc3.setChar(0,4,'0',false);
lc3.setChar(0,3,'c',false);


//FOURTH - 8 DIGIT 7 SEGMENT DISPLAY - VHF-AM PRESET / UHF PRESET / VHF-FM PRESET (CODE) MAX7219 INITIALISATION
lc4.shutdown(0,false); //turn on the display
lc4.setIntensity(0,8);//set the brightness 
lc4.clearDisplay(0); //clear the display 


//FOURTH - 8 DIGIT 7 SEGMENT DISPLAY - VHF-AM PRESET / UHF PRESET / VHF-FM PRESET (CODE) MAX7219 BOOT CODE WHILST AWAITING SOCAT DATA STREAM
// 
lc4.setChar(0,0,'-',false);
lc4.setChar(0,1,'-',false);
lc4.setChar(0,2,'-',false);
lc4.setChar(0,3,'-',false);
lc4.setChar(0,4,'-',false);
lc4.setChar(0,5,'-',false);





}

void loop() {
DcsBios::loop();
} 
